@@ -7,18 +7,18 @@ from .definition import ConnectableObservable, ConnectableObservableEventHandler
 __all__ = ["connectable_observable", "connectable_observable_handler"]
 
 
-_ConnectableObservableDefinition = namedtuple("ConnectableObservable", ["connect", "ref_count", "subscribe"])
+ConnectableObservableDefinition = namedtuple("ConnectableObservableDefinition", ["connect", "ref_count", "subscribe"])
 """Implements ConnectableObservable Protocol."""
 
-_ConnectableObservableHandlerDefinition = namedtuple("ConnectableObservableHandler", ["on_connect", "on_disconnect"])
+ConnectableObservableHandlerDefinition = namedtuple("ConnectableObservableHandlerDefinition", ["on_connect", "on_disconnect"])
 """Implements ConnectableObservableHandler Protocol."""
 
 
 def connectable_observable(connect: ConnectHandler, ref_count: RefCountHandler, subscribe: Subscribe) -> ConnectableObservable:
-    return _ConnectableObservableDefinition(connect=connect, ref_count=ref_count, subscribe=subscribe)
+    return ConnectableObservableDefinition(connect=connect, ref_count=ref_count, subscribe=subscribe)
 
 
 def connectable_observable_handler(
     on_connect: ConnectableObservableEventHandler, on_disconnect: ConnectableObservableEventHandler
 ) -> ConnectableObservableHandler:
-    return _ConnectableObservableHandlerDefinition(on_connect=on_connect, on_disconnect=on_disconnect)
+    return ConnectableObservableHandlerDefinition(on_connect=on_connect, on_disconnect=on_disconnect)
